from django.apps import AppConfig


class NewsletterConfig(AppConfig):
    name = "ycommon.django_modules.newsletter"
    default_auto_field = "django.db.models.AutoField"
